# Ohara Group

Ohara Group is an international group of companies with headquarters in Japan and subsidiaries in Japan (Ohara, Inc.), United States (Ohara Corporation), and Germany (Ohara, GmbH). Ohara manufactures optical and electronic products and also offers measurement services, in particular measurement of refractive indices of solids and liquids.

## External links

- Ohara, Inc.
- Ohara Corporation
- Ohara, GmbH
- Ohara glass catalog